<?php

declare(strict_types=1);

namespace Pinpoint\AdditionalCountries\Setup\Patch\Data;

use Magento\Framework\Setup\ModuleDataSetupInterface;
use Magento\Framework\Setup\Patch\DataPatchInterface;
use Magento\Framework\Setup\Patch\PatchVersionInterface;

/**
 * Add additional countries to the list of countries table
 */
class AddFranceMetroCountryData implements DataPatchInterface, PatchVersionInterface
{
    /**
     * @var string
     */
    private const VERSION = '1.0.0';

    /**
     * @var string
     */
    private const TABLE_NAME_COUNTRY = 'directory_country';

    /**
     * @var array|string[]
     */
    private const COLUMNS = ['country_id', 'iso2_code', 'iso3_code'];

    /**
     * @var \Magento\Framework\Setup\ModuleDataSetupInterface
     */
    private ModuleDataSetupInterface $setup;

    /**
     * @param \Magento\Framework\Setup\ModuleDataSetupInterface $setup
     */
    public function __construct(ModuleDataSetupInterface $setup)
    {
        $this->setup = $setup;
    }

    /**
     * @return array|string[]
     */
    public static function getDependencies(): array
    {
        return [];
    }

    /**
     * @return array|string[]
     */
    public function getAliases(): array
    {
        return [];
    }

    /**
     * Add additional countries to the list of countries table
     *
     * @return void
     */
    public function apply()
    {
        $this->setup->getConnection()->insertArray(
            $this->setup->getTable(self::TABLE_NAME_COUNTRY),
            self::COLUMNS,
            [
                ['FX', 'FX', 'FXX']
            ]
        );
    }

    /**
     * return string
     */
    public static function getVersion(): string
    {
        return self::VERSION;
    }
}
